<?php
/*
    Plugin Name: WebRotate 360 Product Viewer for WordPress
    Plugin URI: http://www.webrotate360.com/360-product-viewer.html
    Description: WebRotate 360 Product Viewer WordPress Integration
    Version: 3.0
    Author: WebRotate 360 LLC
    Author URI: http://www.webrotate360.com
    License: GPLv2
*/

if (!defined("ABSPATH"))
    exit;

class WR360DefaultsConfig
{
    public $viewerWidth;
    public $viewerHeight;
    public $baseWidth;
    public $config;
    public $viewerSkin;
    public $popupSkin;
    public $licensePath;
    public $name;
    public $callback;
    public $rootPath;
    public $isPopupGallery;
    public $zIndexLayers = true;
    public $includePrettyPhoto = true;
    public $useGoogleEvents = false;

    public function init_header()
    {
        $this->viewerSkin = sanitize_text_field(get_option("wr360_viewer_skin"));
        if (empty($this->viewerSkin))
            $this->viewerSkin = "basic";

        $this->popupSkin = sanitize_text_field(get_option("wr360_popup_skin"));
        if (empty($this->popupSkin) || ($this->popupSkin == "default"))
            $this->popupSkin = "pp_default";

        $this->licensePath = esc_url(get_option("wr360_license_path"));
        if (empty($this->licensePath))
            $this->licensePath = plugins_url("webrotate-360-product-viewer/license.lic");

        $dontIncludePrettyPhoto = get_option("wr360_prettyphoto_off");
        if (!empty($dontIncludePrettyPhoto))
            $this->includePrettyPhoto = false;

        $useGoogleEvents = get_option("wr360_use_googleevents");
        if (!empty($useGoogleEvents))
            $this->useGoogleEvents = true;
    }

    public function init_shortcode($atts)
    {
        $this->init_header();

        $extract = shortcode_atts(
            array(
                "name"         => "",
                "width"        => "",
                "height"       => "",
                "rootpath"     => "",
                "config"       => "",
                "basewidth"    => "",
                "gallery"      => "false",
                "imageopacity" => "",
                "viewerskin"   => "",
                "callback"     => ""), $atts);

        $this->viewerWidth  = str_ireplace("px", "", sanitize_text_field(get_option("wr360_viewer_width")));
        $this->viewerHeight = str_ireplace("px", "", sanitize_text_field(get_option("wr360_viewer_height")));
        $this->baseWidth    = str_ireplace("px", "", sanitize_text_field(get_option("wr360_viewer_basewidth")));
        $this->callback     = sanitize_text_field(get_option("wr360_api_ready_callback"));
        $this->config       = esc_url(get_option("wr360_master_config"));
        $imgOpacityOnFlag   = get_option("wr360_transparent_png");

        if (empty($this->viewerWidth))
            $this->viewerWidth = 300;
        if (empty($this->viewerHeight))
            $this->viewerHeight = 300;
        if (empty($this->baseWidth))
            $this->baseWidth = 0;
        if (!empty($imgOpacityOnFlag))
            $this->zIndexLayers = false;

        if (!empty($extract["width"]))
            $this->viewerWidth = str_ireplace("px", "", sanitize_text_field($extract["width"]));
        if (!empty($extract["height"]))
            $this->viewerHeight = str_ireplace("px", "", sanitize_text_field($extract["height"]));
        if (!empty($extract["basewidth"]))
            $this->baseWidth = str_ireplace("px", "", sanitize_text_field($extract["basewidth"]));
        if (!empty($extract["config"]))
            $this->config = esc_url($extract["config"]);
        if (!empty($extract["imageopacity"]))
            $this->zIndexLayers = ($extract["imageopacity"] !== "true");
        if (!empty($extract["viewerskin"]))
            $this->viewerSkin = sanitize_text_field($extract["viewerskin"]);
        if (!empty($extract["callback"]))
            $this->callback = sanitize_text_field($extract["callback"]);

        // Just to keep things short in script.
        if (empty($this->callback))
            $this->callback = "wr360_callback_not_set";

        $this->name = preg_replace('/\s+/', '', $extract["name"]);
        $this->rootPath = esc_url($extract["rootpath"]);

        $this->isPopupGallery = $extract["gallery"];
        if (!empty($this->isPopupGallery))
            $this->isPopupGallery = ($this->isPopupGallery === "true");
    }
}
