<?php
/*
    Plugin Name: WebRotate 360 Product Viewer for WordPress
    Plugin URI: http://www.webrotate360.com/360-product-viewer.html
    Description: WebRotate 360 Product Viewer WordPress Integration
    Version: 3.0
    Author: WebRotate 360 LLC
    Author URI: http://www.webrotate360.com
    License: GPLv2
*/

if (!defined("ABSPATH"))
    exit;

class WR360WooCommerce
{
    public function __construct()
    {
        if (is_admin())
        {
            add_action("woocommerce_product_write_panel_tabs", array($this, "webrotate360_tab_options_tab"));
            add_action("woocommerce_product_write_panels", array($this, "webrotate360_tab_options"));
            add_action("woocommerce_process_product_meta", array($this, "webrotate360_save_product"));
        }
        else
        {
            add_filter("woocommerce_single_product_image_html", array($this, "webrotate360_replace_product_image"), 100);
        }
    }

    public function webrotate360_replace_product_image($content)
    {
        global $post;
        global $product;

        if (empty($post->ID))
            return ($content);

        $wr360config = esc_url(get_post_meta($post->ID, "_wr360config", true));
        $wr360root   = esc_url(get_post_meta($post->ID, "_wr360root", true));

        if (empty($wr360config) && empty($wr360root))
            return ($content);

        $viewAlias = preg_replace('/\s+/', '', $product->get_sku());
        if (empty($viewAlias))
            $viewAlias = $post->ID;

        $defConfig = new WR360DefaultsConfig();
        $defConfig->init_shortcode(array("name"=> $post->ID, "config" => $wr360config, "rootpath" => $wr360root));

        $replace  = "";
        $replace .= "<div class='wr360woowrap'><div id='%s' class='webrotate360' style='width:%s; height:%s;'>";
        $replace .= "<div id='%s' class='wr360_player'></div></div></div>";
        $replace .= "<script language='javascript' type='text/javascript'>";
        $replace .= "jQuery(document).ready(function(){jQuery('#' + '%s').rotator({apiReadyCallback: function(api){var fn = window['%s']; if(typeof fn === 'function'){fn('%s', api);}}, graphicsPath:'%s', licenseFileURL:'%s', rootPath:'%s', configFileURL:'%s', responsiveBaseWidth:%s, zIndexLayersOn:%s, googleEventTracking:%s, viewName:'%s'});});";
        $replace .= "</script>";

        return (sprintf(
            $replace,
            'wr360woo_' . $defConfig->name,
            (strpos($defConfig->viewerWidth, '%') === FALSE) ? $defConfig->viewerWidth . 'px' : $defConfig->viewerWidth,
            $defConfig->viewerHeight . "px",
            'wr360woo_' . $defConfig->name .'_playerid',
            'wr360woo_' . $defConfig->name .'_playerid',
            $defConfig->callback,
            $viewAlias,
            plugins_url("webrotate-360-product-viewer/imagerotator/html/img/" . $defConfig->viewerSkin),
            $defConfig->licensePath,
            $defConfig->rootPath,
            $defConfig->config,
            $defConfig->baseWidth,
            $defConfig->zIndexLayers    ? "true" : "false",
            $defConfig->useGoogleEvents ? "true" : "false",
            $viewAlias));

        return ($content);
    }

    public function webrotate360_save_product($post_id)
    {
        if (isset($_POST["_wr360config"]))
        {
            update_post_meta($post_id, "_wr360config", esc_url($_POST["_wr360config"]));
        }

        if (isset($_POST["_wr360root"]))
        {
            update_post_meta($post_id, "_wr360root", esc_url($_POST["_wr360root"]));
        }
    }

    public function webrotate360_tab_options_tab()
    {
        echo '<li class="custom_tab"><a href="#webrotate360woo_tab_data" id="webrotate360woo_tab">WebRotate 360</a></li>';
    }

    public function webrotate360_tab_options()
    {
        echo '<style type="text/css">a#webrotate360woo_tab:before{content: "\e031" !important;}</style>
            <div id="webrotate360woo_tab_data" class="panel woocommerce_options_panel"><div class="options_group">';

        woocommerce_wp_text_input(array(
            "id" => "_wr360config",
            "label" => "Config File URL",
            "placeholder" => "",
            "desc_tip" => true,
            "description" => sprintf("Config File URL")
        ));

        woocommerce_wp_text_input(array(
            "id" => "_wr360root",
            "label" => "Root Path",
            "placeholder" => "",
            "desc_tip" => true,
            "description" => sprintf("Root Path")
        ));

        echo "</div></div>";
    }
}